.. cpaas-python-sdk documentation master file, created by
   sphinx-quickstart on Mon Oct 14 01:58:27 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


createClient
============

.. automodule:: cpaassdk.client
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules/client.rst
   modules/conversation.rst
   modules/notification.rst
   modules/twofactor.rst